==> file_storage_handler_abm-8.0.67655a0.tar.gz: file_storage_handler_abm-8.0.67655a0/file_storage_handler/entities/file_info.py <==
#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
import hashlib

from sqlalchemy import String, Integer
from sqlalchemy_tools.entity_helpers.decorator import sqlalchemy_dataclass
from sqlalchemy_tools.entity_helpers.fields import sql_field, make_field__created_at
from sqlalchemy_tools.entity_helpers.sqlalchemy_base import sqlalchemy_mapper_registry


@sqlalchemy_dataclass(sqlalchemy_mapper_registry)
class FileInfo:
    key: str = sql_field(String, primary_key=True, nullable=False, allow_init_primary_key=True)
    md5: str = sql_field(String, nullable=False)
    sha512: str = sql_field(String, nullable=False)
    size: int = sql_field(Integer, nullable=False)
    created_at: float = make_field__created_at()

    @classmethod
    def from_bytes(cls, value: bytes, **kwargs) -> 'FileInfo':
        size = len(value)
        md5_hash = generate_md5_hash(value)
        sha512_hash = generate_sha512_hash(value)
        instance = kwargs.get('instance', '')
        instance = f"{instance}_" if instance else instance
        return FileInfo(key=f'{instance}{md5_hash}_{size}', md5=md5_hash, sha512=sha512_hash, size=size, **kwargs)


def generate_md5_hash(payload: bytes | str) -> str:
    m = hashlib.md5()
    payload = payload if isinstance(payload, bytes) else payload.encode('utf-8')
    m.update(payload)
    return m.hexdigest()


def generate_sha512_hash(payload: bytes | str) -> str:
    m = hashlib.sha512()
    payload = payload if isinstance(payload, bytes) else payload.encode('utf-8')
    m.update(payload)
    return m.hexdigest()

==> file_storage_handler_abm-8.0.67680a0.tar.gz: file_storage_handler_abm-8.0.67680a0/file_storage_handler/entities/file_info.py <==
#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
import hashlib

from sqlalchemy import String, Integer
from sqlalchemy_tools.entity_helpers.decorator import sqlalchemy_dataclass
from sqlalchemy_tools.entity_helpers.fields import sql_field, make_field__created_at
from sqlalchemy_tools.entity_helpers.sqlalchemy_base import sqlalchemy_mapper_registry


@sqlalchemy_dataclass(sqlalchemy_mapper_registry)
class FileInfo:
    key: str = sql_field(String, primary_key=True, nullable=False, allow_init_primary_key=True)
    md5: str = sql_field(String, nullable=False)
    sha512: str = sql_field(String, nullable=False)
    size: int = sql_field(Integer, nullable=False)
    created_at: float = make_field__created_at()

    @classmethod
    def from_bytes(cls, value: bytes, **kwargs) -> 'FileInfo':
        size = len(value)
        md5_hash = generate_md5_hash(value)
        sha512_hash = generate_sha512_hash(value)
        instance = kwargs.get('instance')
        instance = f'{instance}_' if instance is not None else ''
        return FileInfo(key=f'{instance}{md5_hash}_{size}', md5=md5_hash, sha512=sha512_hash, size=size, **kwargs)


def generate_md5_hash(payload: bytes | str) -> str:
    m = hashlib.md5()
    payload = payload if isinstance(payload, bytes) else payload.encode('utf-8')
    m.update(payload)
    return m.hexdigest()


def generate_sha512_hash(payload: bytes | str) -> str:
    m = hashlib.sha512()
    payload = payload if isinstance(payload, bytes) else payload.encode('utf-8')
    m.update(payload)
    return m.hexdigest()
